@@ -7,6 +7,7 @@ import pkg_resources
 from flask import Flask, request, render_template
 from flask_bootstrap import Bootstrap
 import os
+import json
 
 # hwrt modules
 import hwrt.utils as utils
@@ -56,6 +57,31 @@ def interactive():
         return render_template('canvas.html')
 
 
+def get_json_result(results, n=10):
+    s = []
+    for res in results[:min(len(results), n)]:
+        s.append({res['semantics']: res['probability']})
+    return json.dumps(s)
+
+
+@app.route('/worker', methods=['POST', 'GET'])
+def worker():
+    # Test with
+    # wget --post-data 'classify=%5B%5B%7B%22x%22%3A334%2C%22y%22%3A407%2C%22time%22%3A1417704378719%7D%5D%5D' http://127.0.0.1:5000/worker
+    if request.method == 'POST':
+        raw_data_json = request.form['classify']
+        # TODO: Check recording
+        # TODO: Submit recorded json to database
+        # Classify
+        model_path = pkg_resources.resource_filename('hwrt', 'misc/')
+        model = os.path.join(model_path, "model.tar")
+        results = utils.evaluate_model_single_recording(model, raw_data_json)
+        return get_json_result(results, n=10)
+    else:
+        # Page where the user can enter a recording
+        return "Classification Worker (Version TODO)"
+
+
 def get_parser():
     """Return the parser object for this script."""
     from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter
